@@ -595,7 +595,7 @@ def drawEICAround(ms1Data, mz, rt, outDir, pltName="TBD.png",
         return [rtSeq, intSeq]
 
 
-def dotProd(ms2A, ms2B, mzTol=0.02):
+def dotProd(ms2A, ms2B, mzTol=0.02, rep='simple'):
     """
     Function to calculate the MS2 similarity by dot product.
     Return 2.0 if MS2 does not exist.
@@ -639,6 +639,7 @@ def dotProd(ms2A, ms2B, mzTol=0.02):
         minDiff = diff.min()
 
     unmatched = int2[mz2 != -1]
+    matchNum = len(int2[mz2 == -1])
     if len(unmatched) != 0:
         t = np.row_stack((np.zeros(len(unmatched)), unmatched))
         intTable = np.column_stack((intTable, t))
@@ -646,7 +647,10 @@ def dotProd(ms2A, ms2B, mzTol=0.02):
     dp = np.inner(intTable[0], intTable[1]) / (
             np.inner(intTable[0], intTable[0]) * np.inner(intTable[1], intTable[1])) ** 0.5
 
-    return dp
+    if rep == 'simple':
+        return dp
+    elif rep == 'full':
+        return {'dotprod': dp, 'matchNumber': len(matchNum)}
 
 
 def numberUniqueMS2(d, rtTol=1.0, precsMzTol=0.01, dpTol=0.95):
